print("import: 'thefuzz'")
import thefuzz

print("import: 'thefuzz.StringMatcher'")
import thefuzz.StringMatcher

print("import: 'thefuzz.fuzz'")
import thefuzz.fuzz

print("import: 'thefuzz.process'")
import thefuzz.process

print("import: 'thefuzz.string_processing'")
import thefuzz.string_processing

print("import: 'thefuzz.utils'")
import thefuzz.utils

